pub struct LayerStats {Show 56 fields
pub index: usize,
pub util: f64,
pub util_protected_frac: f64,
pub util_protected_preempt_frac: f64,
pub util_open_frac: f64,
pub util_frac: f64,
pub tasks: u32,
pub total: u64,
pub sel_local: f64,
pub enq_local: f64,
pub enq_wakeup: f64,
pub enq_expire: f64,
pub enq_reenq: f64,
pub enq_dsq: f64,
pub min_exec: f64,
pub min_exec_us: u64,
pub open_idle: f64,
pub preempt: f64,
pub preempt_xllc: f64,
pub preempt_xnuma: f64,
pub preempt_first: f64,
pub preempt_idle: f64,
pub preempt_fail: f64,
pub affn_viol: f64,
pub keep: f64,
pub keep_fail_max_exec: f64,
pub keep_fail_busy: f64,
pub is_excl: u32,
pub excl_collision: f64,
pub excl_preempt: f64,
pub yielded: f64,
pub yield_ignore: u64,
pub migration: f64,
pub xnuma_migration: f64,
pub xllc_migration: f64,
pub xllc_migration_skip: f64,
pub xlayer_wake: f64,
pub xlayer_rewake: f64,
pub llc_drain_try: f64,
pub llc_drain: f64,
pub skip_remote_node: f64,
pub cpus: Vec<u64>,
pub cur_nr_cpus: u32,
pub min_nr_cpus: u32,
pub max_nr_cpus: u32,
pub nr_llc_cpus: Vec<u32>,
pub slice_us: u64,
pub llc_fracs: Vec<f64>,
pub llc_lats: Vec<f64>,
pub membw_pct: f64,
pub dsq_insert_ewma: f64,
pub node_utils: Vec<f64>,
pub node_pinned_utils: Vec<f64>,
pub node_pinned_tasks: Vec<u64>,
pub node_loads: Vec<f64>,
pub xnuma_active: u32,
}Fields
index: usizeindex
util: f64Total CPU utilization (100% means one full CPU)
util_protected_frac: f64Protected CPU utilization %
util_protected_preempt_frac: f64Preempt-protected CPU utilization %
util_open_frac: f64Open CPU utilization %
util_frac: f64fraction of total CPU utilization
tasks: u32number of tasks
total: u64count of sched events during the period
sel_local: f64% dispatched into idle CPU from select_cpu
enq_local: f64% dispatched into idle CPU from enqueue
enq_wakeup: f64% enqueued after wakeup
enq_expire: f64% enqueued after slice expiration
enq_reenq: f64% re-enqueued due to RT preemption
enq_dsq: f64% enqueued into the layer’s LLC DSQs
min_exec: f64count of times exec duration < min_exec_us
min_exec_us: u64total exec durations extended due to min_exec_us
open_idle: f64% dispatched into idle CPUs occupied by other layers
preempt: f64% preempted other tasks
preempt_xllc: f64% preempted XLLC tasks
preempt_xnuma: f64% preempted across NUMA nodes
preempt_first: f64% first-preempted other tasks
preempt_idle: f64% idle-preempted other tasks
preempt_fail: f64% attempted to preempt other tasks but failed
affn_viol: f64% violated config due to CPU affinity
keep: f64% continued executing after slice expiration
keep_fail_max_exec: f64% disallowed to continue executing due to max_exec
keep_fail_busy: f64% disallowed to continue executing due to other tasks
is_excl: u32whether is exclusive
excl_collision: f64count of times an excl task skipped a CPU as the sibling was also excl
excl_preempt: f64% a sibling CPU was preempted for an exclusive task
yielded: f64% yielded
yield_ignore: u64count of times yield was ignored
migration: f64% migrated across CPUs
xnuma_migration: f64% migrated across NUMA nodes
xllc_migration: f64% migrated across LLCs
xllc_migration_skip: f64% migration skipped across LLCs due to xllc_mig_min_us
xlayer_wake: f64% wakers across layers
xlayer_rewake: f64% rewakers across layers where waker has waken the task previously
llc_drain_try: f64% LLC draining tried
llc_drain: f64% LLC draining succeeded
skip_remote_node: f64% skip LLC dispatch on remote node
cpus: Vec<u64>mask of allocated CPUs
cur_nr_cpus: u32count of CPUs assigned
min_nr_cpus: u32minimum # of CPUs assigned
max_nr_cpus: u32maximum # of CPUs assigned
nr_llc_cpus: Vec<u32>count of CPUs assigned per LLC
slice_us: u64slice duration config
llc_fracs: Vec<f64>Per-LLC scheduling event fractions
llc_lats: Vec<f64>Per-LLC average latency
membw_pct: f64Layer memory bandwidth as a % of total allowed (0 for “no limit”
dsq_insert_ewma: f64DSQ insertion ratio EWMA (10s window)
node_utils: Vec<f64>Per-node layer utilization (100% = one full CPU)
node_pinned_utils: Vec<f64>Per-node pinned task utilization (100% = one full CPU)
node_pinned_tasks: Vec<u64>Per-node pinned task counts
node_loads: Vec<f64>Per-node load (100% = one full CPU, from duty cycle sum)
xnuma_active: u32Whether xnuma gating is active for this layer (0/1)
Implementations