pub struct SysStats {Show 28 fields
pub at: f64,
pub nr_nodes: usize,
pub total: u64,
pub local_sel: f64,
pub local_enq: f64,
pub open_idle: f64,
pub affn_viol: f64,
pub hi_fb: f64,
pub lo_fb: f64,
pub excl_collision: f64,
pub excl_preempt: f64,
pub excl_idle: f64,
pub excl_wakeup: f64,
pub proc_ms: u64,
pub busy: f64,
pub util: f64,
pub hi_fb_util: f64,
pub lo_fb_util: f64,
pub antistall: u64,
pub skip_preempt: u64,
pub fixup_vtime: u64,
pub preempting_mismatch: u64,
pub fallback_cpus: BTreeMap<u32, u32>,
pub fallback_cpu_util: f64,
pub layers: BTreeMap<String, LayerStats>,
pub gpu_tasks_affinitized: u64,
pub gpu_task_affinitization_ms: u64,
pub system_cpu_util_ewma: f64,
}Fields
at: f64timestamp
nr_nodes: usizeof NUMA nodes
total: u64sched events during the period
local_sel: f64% dispatched directly into an idle CPU from select_cpu
local_enq: f64% dispatched directly into an idle CPU from enqueue
open_idle: f64% open layer tasks scheduled into allocated but idle CPUs
affn_viol: f64% violated config due to CPU affinity
hi_fb: f64% sent to hi fallback DSQs
lo_fb: f64% sent to lo fallback DSQs
excl_collision: f64count of times an excl task skipped a CPU as the sibling was also excl
excl_preempt: f64count of times a sibling CPU was preempted for an excl task
excl_idle: f64count of times a CPU skipped dispatching due to an excl task on the sibling
excl_wakeup: f64count of times an idle sibling CPU was woken up after an excl task is finished
proc_ms: u64CPU time this binary consumed during the period
busy: f64CPU busy % (100% means all CPU)
util: f64CPU util % (100% means one CPU)
hi_fb_util: f64CPU util % used by hi fallback DSQs
lo_fb_util: f64CPU util % used by lo fallback DSQs
antistall: u64Number of tasks dispatched via antistall
skip_preempt: u64Number of times preemptions of non-scx tasks were avoided
fixup_vtime: u64Number of times vtime was out of range and fixed up
preempting_mismatch: u64Number of times cpuc->preempting_task didn’t come on the CPU
fallback_cpus: BTreeMap<u32, u32>per-node fallback CPUs
fallback_cpu_util: f64per-layer statistics
layers: BTreeMap<String, LayerStats>fallback CPU util %
gpu_tasks_affinitized: u64Number of gpu tasks affinitized since scheduler start
gpu_task_affinitization_ms: u64Time (in ms) of last affinitization run.
system_cpu_util_ewma: f64System CPU utilization EWMA (10s window)
Implementations